/**
 * A BoundedAngle represents an angle in the range 
 * (-180, 180] in degrees or (-pi, pi] in radians.
 * 
 * @author Andrew Vardy
 */

import static java.lang.Math.PI;

public class BoundedAngle {
	private final double valueRadians;
	
	public BoundedAngle(double angle, boolean inDegrees) {
		if (inDegrees)
			angle = Math.toRadians(angle);
		
		// If the angle (in radians) lies outside the acceptable
		// range, subtract or add 2 PI until it lies within
		// the acceptable range.
		while ( angle > PI )
			angle -= 2.0 * PI;
		while ( angle <= -PI)
			angle += 2.0 * PI;
		
		valueRadians = angle;
	}

	public double getValueDegrees() {
		return Math.toDegrees(valueRadians);
	}

	public BoundedAngle add(BoundedAngle angle2) {
		return new BoundedAngle(
				valueRadians + angle2.valueRadians, false);
	}
}
