/**
 * First example of the usage of JUnit.  Here we test
 * the BoundedAngle class.
 */
import static org.junit.Assert.assertEquals;
import org.junit.Test;

public class TestBoundedAngle {
	private final static double DELTA = 1e-5;
	
	/**
	 * Check that the angle remains bounded even when
	 * initialized to an out-of-bounds value.
	 */
	@Test public void checkRange() {
		BoundedAngle a1 = new BoundedAngle(182.0 , true);
		assertEquals( a1.getValueDegrees(), -178.0, DELTA );
		
		BoundedAngle a2 = new BoundedAngle(-182.0 , true);
		assertEquals( a2.getValueDegrees(), 178.0, DELTA );
	}

	/**
	 * Test the add method, in a simple way that does not
	 * exercise the "boundedness" of BoundedAngle (i.e the
	 * fact that the angle should always lie in the range
	 * (-180, 180]).
	 */
	@Test public void simpleAdd() {
		BoundedAngle angle1 = new BoundedAngle(40.0, true);
		BoundedAngle angle2 = new BoundedAngle(-10.0, true);
		
		BoundedAngle angle3 = angle1.add(angle2);
		BoundedAngle angle4 = angle2.add(angle1);
		
		// Test that addition in either order yields 30.
		assertEquals( angle3.getValueDegrees(), 30.0, DELTA );
		assertEquals( angle4.getValueDegrees(), 30.0, DELTA );
		
		// Check that the addition operation did not alter
		// the previous angles stored in either angle1 or 2.
		assertEquals( angle1.getValueDegrees(), 40.0, DELTA );
		assertEquals( angle2.getValueDegrees(), -10.0, DELTA );
	}
}






















/*
BoundedAngle a1 = new BoundedAngle(182.0, true);
assertEquals( a1.getValueDegrees(), -178.0, DELTA );

// Try the other way.
BoundedAngle a2 = new BoundedAngle(-182.0, true);
assertEquals( a2.getValueDegrees(), 178.0, DELTA );

// Try a couple of larger values.
BoundedAngle a3 = new BoundedAngle(362.0, true);
BoundedAngle a4 = new BoundedAngle(544.0, true);
assertEquals( a3.getValueDegrees(), 2.0, DELTA );
assertEquals( a4.getValueDegrees(), -176.0, DELTA );	
*/