/**
 * Second example of the use of JUnit.  Here we test the
 * IntVect class and introduce the notion of a test fixture.
 * Methods annotated with @Before are used to setup the
 * test fixture prior to every test (a test is any method
 * annotated with @Test).  Similarly, @After is used to
 * annotate the method used to clean up the test fixture.
 * We don't really require such a method here, but we have
 * one anyway.
 */

import static org.junit.Assert.assertEquals;

import org.junit.After;
import org.junit.Before;
import org.junit.Test;

public class TestIntVect {
	
	// The test fixture.
	IntVect fVec;

	// Create the test fixture (called before each test).
	@Before
	public void setUp() throws Exception {
        fVec = new IntVect(4);
        fVec.add(10);
        fVec.add(20);
        fVec.add(30);
        fVec.add(40);
	}

	// Get rid of the test fixture (called after each test).
	@After
	public void tearDown() throws Exception {
		// Nothing to do.
	}

	@Test
	public void testSize() {
		IntVect v1 = new IntVect(1);
		assertEquals( v1.size(), 0 );
		
		// Check if setting the capacity makes
		// any difference.
		IntVect v2 = new IntVect(20);
		assertEquals( v2.size(), 0 );
		
		// Check for a non-empty IntVect.
		assertEquals( fVec.size(), 4 );
	}
	
	@Test
	public void testAdd() {		
		// Check that the test fixture was created
		// properly.
		for (int i=1; i<=4; i++ )
			assertEquals( fVec.get(i-1), i*10 );
		
		// Try adding into an empty vector.
		IntVect v1 = new IntVect(1);
		v1.add(10);
		assertEquals( v1.get(0), 10 );
	}
}
